@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: either
 version: 4.4.1
-id: either-4.4.1-6e9670c0aa10adc0c05cea76c41fcbb1
-key: eithe_0Q1zua8x1k4AxBVAOxuEUE
+id: either-4.4.1-02b52c35841743771b37e0d5948e3cc8
+key: eithe_3kiXOfQlXWi4ztU2aTsPak
 license: BSD3
 copyright: Copyright (C) 2008-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -22,19 +22,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/either-4.4.1
-hs-libraries: HSeither-4.4.1-0Q1zua8x1k4AxBVAOxuEUE
+hs-libraries: HSeither-4.4.1-3kiXOfQlXWi4ztU2aTsPak
 depends:
     MonadRandom-0.4.2.2-41c453a4d3603a1aafaf1f31fe6ac694
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
+    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
+    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
     mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
 haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
